@@ -1,35 +1,40 @@
 /****************************************************************************
 **
-** Copyright (C) 2004-2007 Trolltech ASA. All rights reserved.
+** Copyright (C) 2004-2008 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the example classes of the Qt Toolkit.
 **
 ** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/
+** License versions 2.0 or 3.0 as published by the Free Software
+** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
+** included in the packaging of this file.  Alternatively you may (at
+** your option) use any later version of the GNU General Public
+** License if such license has been publicly approved by Trolltech ASA
+** (or its successors, if any) and the KDE Free Qt Foundation. In
+** addition, as a special exception, Trolltech gives you certain
+** additional rights. These rights are described in the Trolltech GPL
+** Exception version 1.1, which can be found at
+** http://www.trolltech.com/products/qt/gplexception/ and in the file
+** GPL_EXCEPTION.txt in this package.
 **
-** If you are unsure which license is appropriate for your use, please
+** Please review the following information to ensure GNU General
+** Public Licensing requirements will be met:
+** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
+** you are unsure which license is appropriate for your use, please
 ** review the following information:
 ** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
 ** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.0, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** In addition, as a special exception, Trolltech, as the sole
+** copyright holder for Qt Designer, grants users of the Qt/Eclipse
+** Integration plug-in the right for the Qt/Eclipse Integration to
+** link to functionality provided by Qt Designer and its related
+** libraries.
 **
-** In addition, as a special exception, Trolltech, as the sole copyright
-** holder for Qt Designer, grants users of the Qt/Eclipse Integration
-** plug-in the right for the Qt/Eclipse Integration to link to
-** functionality provided by Qt Designer and its related libraries.
-**
-** Trolltech reserves all rights not expressly granted herein.
-** 
-** Trolltech ASA (c) 2007
+** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
+** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
+** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
+** granted herein.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -44,19 +49,6 @@
 
 #include <QtCore>
 
-quint32 qntoh(quint32 source)
-{
-#if Q_BYTE_ORDER == Q_BIG_ENDIAN
-    return source;
-#else
-    return 0
-        | ((source & 0x000000ff) << 24)
-        | ((source & 0x0000ff00) << 8)
-        | ((source & 0x00ff0000) >> 8)
-        | ((source & 0xff000000) >> 24);
-#endif
-}
-
 TrackerClient::TrackerClient(TorrentClient *downloader, QObject *parent)
     : QObject(parent), torrentDownloader(downloader)
 {
@@ -107,41 +99,12 @@ void TrackerClient::fetchPeerList()
     // Prepare connection details
     QUrl url(metaInfo.announceUrl());
 
-    QByteArray infoHash = torrentDownloader->infoHash();
-    unsigned int *messageDigest = (unsigned int *)infoHash.constData();
-
     // Percent encode the hash
-    QByteArray encodedSum;
-    const char hex[] = "0123456789ABCDEF";
-    unsigned char chars[4];
-
-    for (int i = 0; i < 5; ++i) {
-        unsigned int digest = qntoh(messageDigest[i]);
-        chars[0] = (digest & 0xff000000) >> 24;
-        chars[1] = (digest & 0x00ff0000) >> 16;
-        chars[2] = (digest & 0x0000ff00) >> 8;
-        chars[3] = (digest & 0x000000ff);
-
-        for (int j = 0; j < 4; ++j) {
-            unsigned char c = chars[j];
-            if ((c >= '0' && c <= '9')
-                || (c >= 'a' && c <= 'z')
-                || (c >= 'A' && c <= 'Z'))
-                encodedSum += c;
-            else switch (c) {
-            case '$': case '-': case '_': case '.':
-            case '+': case '!': case '*': case '\'':
-            case '(': case ')':
-                encodedSum += c;
-                break;
-            default: {
-                encodedSum += "%";
-                encodedSum += hex[(c & 0xf0) >> 4];
-                encodedSum += hex[c & 0xf];
-                break;
-            }
-            }
-        }
+    QByteArray infoHash = torrentDownloader->infoHash();
+    QString encodedSum;
+    for (int i = 0; i < infoHash.size(); ++i) {
+        encodedSum += '%';
+        encodedSum += QString::number(infoHash[i], 16).right(2).rightJustified(2, '0');
     }
 
     bool seeding = (torrentDownloader->state() == TorrentClient::Seeding);
