@@ -1,33 +1,40 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2007 Trolltech ASA. All rights reserved.
+** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
 ** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/
+** License versions 2.0 or 3.0 as published by the Free Software
+** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
+** included in the packaging of this file.  Alternatively you may (at
+** your option) use any later version of the GNU General Public
+** License if such license has been publicly approved by Trolltech ASA
+** (or its successors, if any) and the KDE Free Qt Foundation. In
+** addition, as a special exception, Trolltech gives you certain
+** additional rights. These rights are described in the Trolltech GPL
+** Exception version 1.1, which can be found at
+** http://www.trolltech.com/products/qt/gplexception/ and in the file
+** GPL_EXCEPTION.txt in this package.
 **
-** If you are unsure which license is appropriate for your use, please
+** Please review the following information to ensure GNU General
+** Public Licensing requirements will be met:
+** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
+** you are unsure which license is appropriate for your use, please
 ** review the following information:
 ** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
 ** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.0, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** In addition, as a special exception, Trolltech, as the sole
+** copyright holder for Qt Designer, grants users of the Qt/Eclipse
+** Integration plug-in the right for the Qt/Eclipse Integration to
+** link to functionality provided by Qt Designer and its related
+** libraries.
 **
-** In addition, as a special exception, Trolltech, as the sole copyright
-** holder for Qt Designer, grants users of the Qt/Eclipse Integration
-** plug-in the right for the Qt/Eclipse Integration to link to
-** functionality provided by Qt Designer and its related libraries.
-**
-** Trolltech reserves all rights not expressly granted herein.
+** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
+** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
+** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
+** granted herein.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -106,8 +113,8 @@ QFontListView::QFontListView(QWidget *parent)
   \mainclass
   \brief The QFontDialog class provides a dialog widget for selecting a font.
 
-  The usual way to use this class is to call one of the static convenience
-  functions, e.g. getFont().
+    A font dialog is created through one of the static getFont()
+    functions.
 
   Examples:
 
@@ -383,15 +390,12 @@ QFontDialog::~QFontDialog()
   If the user clicks \gui OK, the selected font is returned. If the user
   clicks \gui Cancel, the \a initial font is returned.
 
-  The dialog is constructed with the given \a parent.  \a caption is
+  The dialog is constructed with the given \a parent. \a caption is
   shown as the window title of the dialog and  \a initial is the
   initially selected font. If the \a ok parameter is not-null, the
   value it refers to is set to true if the user clicks \gui OK, and
   set to false if the user clicks \gui Cancel.
 
-  This static function is less flexible than the full QFontDialog
-  object, but is convenient and easy to use.
-
   Examples:
   \code
     bool ok;
@@ -439,9 +443,6 @@ QFont QFontDialog::getFont(bool *ok, const QFont &initial,
   to true if the user clicks \gui OK, and false if the user clicks
   \gui Cancel.
 
-  This static function is less functional than the full QFontDialog
-  object, but is convenient and easy to use.
-
   Example:
   \code
     bool ok;
