@@ -1,20 +1,40 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2006 Trolltech ASA. All rights reserved.
+** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
 ** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** License versions 2.0 or 3.0 as published by the Free Software
+** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
+** included in the packaging of this file.  Alternatively you may (at
+** your option) use any later version of the GNU General Public
+** License if such license has been publicly approved by Trolltech ASA
+** (or its successors, if any) and the KDE Free Qt Foundation. In
+** addition, as a special exception, Trolltech gives you certain
+** additional rights. These rights are described in the Trolltech GPL
+** Exception version 1.1, which can be found at
+** http://www.trolltech.com/products/qt/gplexception/ and in the file
+** GPL_EXCEPTION.txt in this package.
 **
-** If you are unsure which license is appropriate for your use, please
+** Please review the following information to ensure GNU General
+** Public Licensing requirements will be met:
+** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
+** you are unsure which license is appropriate for your use, please
 ** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
+** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
+** or contact the sales department at sales@trolltech.com.
+**
+** In addition, as a special exception, Trolltech, as the sole
+** copyright holder for Qt Designer, grants users of the Qt/Eclipse
+** Integration plug-in the right for the Qt/Eclipse Integration to
+** link to functionality provided by Qt Designer and its related
+** libraries.
+**
+** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
+** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
+** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
+** granted herein.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -37,6 +57,7 @@
 #include <QtGui/qpen.h>
 #include <QtGui/qbrush.h>
 #include <QtGui/qmatrix.h>
+#include <QtGui/qtransform.h>
 #include <QtGui/qfontinfo.h>
 #include <QtGui/qfontmetrics.h>
 #endif
@@ -55,6 +76,7 @@ class QPen;
 class QPolygon;
 class QTextItem;
 class QMatrix;
+class QTransform;
 
 class Q_GUI_EXPORT QPainter
 {
@@ -66,7 +88,8 @@ public:
     enum RenderHint {
         Antialiasing = 0x01,
         TextAntialiasing = 0x02,
-        SmoothPixmapTransform = 0x04
+        SmoothPixmapTransform = 0x04,
+        HighQualityAntialiasing = 0x08
     };
 
     Q_DECLARE_FLAGS(RenderHints, RenderHint)
@@ -95,7 +118,21 @@ public:
         CompositionMode_DestinationOut,
         CompositionMode_SourceAtop,
         CompositionMode_DestinationAtop,
-        CompositionMode_Xor
+        CompositionMode_Xor,
+
+        //svg 1.2 blend modes
+        CompositionMode_Plus,
+        CompositionMode_Multiply,
+        CompositionMode_Screen,
+        CompositionMode_Overlay,
+        CompositionMode_Darken,
+        CompositionMode_Lighten,
+        CompositionMode_ColorDodge,
+        CompositionMode_ColorBurn,
+        CompositionMode_HardLight,
+        CompositionMode_SoftLight,
+        CompositionMode_Difference,
+        CompositionMode_Exclusion
     };
     void setCompositionMode(CompositionMode mode);
     CompositionMode compositionMode() const;
@@ -135,11 +172,7 @@ public:
     QPainterPath clipPath() const;
 
     void setClipRect(const QRectF &, Qt::ClipOperation op = Qt::ReplaceClip);
-#ifdef QT_EXPERIMENTAL_REGIONS
     void setClipRect(const QRect &, Qt::ClipOperation op = Qt::ReplaceClip);
-#else
-    inline void setClipRect(const QRect &, Qt::ClipOperation op = Qt::ReplaceClip);
-#endif
     inline void setClipRect(int x, int y, int w, int h, Qt::ClipOperation op = Qt::ReplaceClip);
 
     void setClipRegion(const QRegion &, Qt::ClipOperation op = Qt::ReplaceClip);
@@ -158,10 +191,19 @@ public:
     const QMatrix &deviceMatrix() const;
     void resetMatrix();
 
+    void setTransform(const QTransform &transform, bool combine = false);
+    const QTransform &transform() const;
+    const QTransform &deviceTransform() const;
+    void resetTransform();
+
     void setWorldMatrix(const QMatrix &matrix, bool combine = false);
     const QMatrix &worldMatrix() const;
+    
+    void setWorldTransform(const QTransform &matrix, bool combine = false);
+    const QTransform &worldTransform() const;
 
     QMatrix combinedMatrix() const;
+    QTransform combinedTransform() const;
 
     void setMatrixEnabled(bool enabled);
     bool matrixEnabled() const;
@@ -333,6 +375,7 @@ public:
     void setRenderHint(RenderHint hint, bool on = true);
     void setRenderHints(RenderHints hints, bool on = true);
     RenderHints renderHints() const;
+    inline bool testRenderHint(RenderHint hint) const { return renderHints() & hint; }
 
     QPaintEngine *paintEngine() const;
 
@@ -396,7 +439,7 @@ public:
 
     inline QT3_SUPPORT void setWorldXForm(bool enabled) { setMatrixEnabled(enabled); }
     inline QT3_SUPPORT bool hasWorldXForm() const { return matrixEnabled(); }
-    inline QT3_SUPPORT void resetXForm() { resetMatrix(); }
+    inline QT3_SUPPORT void resetXForm() { resetTransform(); }
 
     inline QT3_SUPPORT void setViewXForm(bool enabled) { setViewTransformEnabled(enabled); }
     inline QT3_SUPPORT bool hasViewXForm() const { return viewTransformEnabled(); }
@@ -432,6 +475,8 @@ private:
     friend class QX11PaintEnginePrivate;
     friend class QWin32PaintEngine;
     friend class QWin32PaintEnginePrivate;
+    friend class QRasterPaintEngine;
+    friend class QAlphaPaintEngine;
 };
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(QPainter::RenderHints)
@@ -615,20 +660,9 @@ inline void QPainter::drawChord(int x, int y, int w, int h, int a, int alen)
 
 inline void QPainter::setClipRect(int x, int y, int w, int h, Qt::ClipOperation op)
 {
-#ifdef QT_EXPERIMENTAL_REGIONS
     setClipRect(QRect(x, y, w, h), op);
-#else
-    setClipRect(QRectF(x, y, w, h), op);
-#endif
 }
 
-#ifndef QT_EXPERIMENTAL_REGIONS
-inline void QPainter::setClipRect(const QRect &rect, Qt::ClipOperation op)
-{
-    setClipRect(QRectF(rect), op);
-}
-#endif
-
 inline void QPainter::eraseRect(const QRect &rect)
 {
     eraseRect(QRectF(rect));
