@@ -1,35 +1,40 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2007 Trolltech ASA. All rights reserved.
+** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the tools applications of the Qt Toolkit.
 **
 ** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/
+** License versions 2.0 or 3.0 as published by the Free Software
+** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
+** included in the packaging of this file.  Alternatively you may (at
+** your option) use any later version of the GNU General Public
+** License if such license has been publicly approved by Trolltech ASA
+** (or its successors, if any) and the KDE Free Qt Foundation. In
+** addition, as a special exception, Trolltech gives you certain
+** additional rights. These rights are described in the Trolltech GPL
+** Exception version 1.1, which can be found at
+** http://www.trolltech.com/products/qt/gplexception/ and in the file
+** GPL_EXCEPTION.txt in this package.
 **
-** If you are unsure which license is appropriate for your use, please
+** Please review the following information to ensure GNU General
+** Public Licensing requirements will be met:
+** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
+** you are unsure which license is appropriate for your use, please
 ** review the following information:
 ** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
 ** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.0, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** In addition, as a special exception, Trolltech, as the sole
+** copyright holder for Qt Designer, grants users of the Qt/Eclipse
+** Integration plug-in the right for the Qt/Eclipse Integration to
+** link to functionality provided by Qt Designer and its related
+** libraries.
 **
-** In addition, as a special exception, Trolltech, as the sole copyright
-** holder for Qt Designer, grants users of the Qt/Eclipse Integration
-** plug-in the right for the Qt/Eclipse Integration to link to
-** functionality provided by Qt Designer and its related libraries.
-**
-** Trolltech reserves all rights not expressly granted herein.
-** 
-** Trolltech ASA (c) 2007
+** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
+** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
+** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
+** granted herein.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -117,11 +122,11 @@ struct QDBusSlotCache
 };
 Q_DECLARE_METATYPE(QDBusSlotCache)
 
-class CallDeliveryEvent: public QMetaCallEvent
+class QDBusCallDeliveryEvent: public QMetaCallEvent
 {
 public:
-    CallDeliveryEvent(const QDBusConnection &c, int id, QObject *sender,
-                      const QDBusMessage &msg, const QList<int> &types, int f = 0)
+    QDBusCallDeliveryEvent(const QDBusConnection &c, int id, QObject *sender,
+                           const QDBusMessage &msg, const QList<int> &types, int f = 0)
         : QMetaCallEvent(id, sender), connection(c), message(msg), metaTypes(types), flags(f)
         { }
 
@@ -138,16 +143,16 @@ private:
     int flags;
 };
 
-class ActivateObjectEvent: public QMetaCallEvent
+class QDBusActivateObjectEvent: public QMetaCallEvent
 {
 public:
-    ActivateObjectEvent(const QDBusConnection &c, QObject *sender,
-                        const QDBusConnectionPrivate::ObjectTreeNode &n,
-                        int p, const QDBusMessage &m, QSemaphore *s = 0)
+    QDBusActivateObjectEvent(const QDBusConnection &c, QObject *sender,
+                             const QDBusConnectionPrivate::ObjectTreeNode &n,
+                             int p, const QDBusMessage &m, QSemaphore *s = 0)
         : QMetaCallEvent(-1, sender, 0, 0, 0, s), connection(c), node(n),
           pathStartPos(p), message(m), handled(false)
         { }
-    ~ActivateObjectEvent();
+    ~QDBusActivateObjectEvent();
 
     int placeMetaCall(QObject *);
 
