@@ -184,12 +184,6 @@
         <source>Type in the text to search for.</source>
         <translation>検索するテキストを入力してください。</translation>
     </message>
-    <message>
-        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/finddialog.cpp" line="14"/>
-        <source></source>
-        <comment>Choose Edit|Find from the menu bar or press Ctrl+F to pop up the Find dialog</comment>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>FormHolder</name>
@@ -911,15 +905,6 @@
         <translation>完了</translation>
     </message>
 </context>
-<context>
-    <name>MsgEdit</name>
-    <message>
-        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/msgedit.cpp" line="14"/>
-        <source></source>
-        <comment>This is the right panel of the main window.</comment>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>PageCurl</name>
     <message>
@@ -1025,12 +1010,6 @@
         <source>&amp;Translation:</source>
         <translation>訳(&amp;T):</translation>
     </message>
-    <message>
-        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/phrasebookbox.cpp" line="14"/>
-        <source></source>
-        <comment>Go to Phrase &gt; Edit Phrase Book... The dialog that pops up is a PhraseBookBox.</comment>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>PhraseModel</name>
@@ -1608,12 +1587,6 @@ All files (*)</source>
         <source>&amp;Window</source>
         <translation>ウィンドウ(&amp;W)</translation>
     </message>
-    <message>
-        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="14"/>
-        <source></source>
-        <comment>This is the application&apos;s main window.</comment>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="302"/>
         <source>%1 translation</source>
@@ -1652,7 +1625,7 @@ All files (*)</source>
     </message>
     <message>
         <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/trwindow.cpp" line="943"/>
-        <source>&lt;center&gt;&lt;img src=&quot;:/images/splash.png&quot;/&gt;&lt;/img&gt;&lt;p&gt;%1&lt;/p&gt;&lt;/center&gt;&lt;p&gt;Qt Linguist is a tool for adding translations to Qt applications.&lt;/p&gt;&lt;p&gt;%2&lt;/p&gt;&lt;p&gt;Copyright (C) 2000-2007 Trolltech ASA. All rights reserved.&lt;/p&gt;&lt;p&gt;The program is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.&lt;/p&gt;</source>
+        <source>&lt;center&gt;&lt;img src=&quot;:/images/splash.png&quot;/&gt;&lt;/img&gt;&lt;p&gt;%1&lt;/p&gt;&lt;/center&gt;&lt;p&gt;Qt Linguist is a tool for adding translations to Qt applications.&lt;/p&gt;&lt;p&gt;%2&lt;/p&gt;&lt;p&gt;Copyright (C) 2000-2008 Trolltech ASA. All rights reserved.&lt;/p&gt;&lt;p&gt;The program is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.&lt;/p&gt;</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1739,7 +1712,7 @@ All files (*)</source>
     <message>
         <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/translationsettings.ui" line="53"/>
         <source>Country</source>
-        <translation>国</translation>
+        <translation type="obsolete">国</translation>
     </message>
     <message>
         <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/translationsettings.ui" line="40"/>
@@ -1756,6 +1729,11 @@ All files (*)</source>
         <source>Target language</source>
         <translation>翻訳先の言語</translation>
     </message>
+    <message>
+        <location filename="../../../../data/depot/qt/4.3/tools/linguist/linguist/translationsettings.ui" line="53"/>
+        <source>Country/Region</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>TranslationSettingsDialog</name>
